@@ -35,7 +35,7 @@ from math import ceil
 import time
 
 from aiorpcx.curio import (
-    TaskGroup, TaskTimeout, CancelledError, timeout_after, sleep
+    TaskGroup, TaskTimeout, timeout_after, sleep
 )
 from aiorpcx.framing import (
     NewlineFramer, BitcoinFramer, BadMagicError, BadChecksumError, OversizedPayloadError
@@ -188,7 +188,6 @@ class SessionBase:
         '''Called just before disconnecting from the session, if it was consuming too
         much resources.
         '''
-        pass
 
     def recalc_concurrency(self):
         '''Call to recalculate sleeps and concurrency for the session.  Called automatically if
@@ -216,11 +215,19 @@ class SessionBase:
         self._incoming_concurrency.set_target(target)
 
     async def _process_messages(self, recv_message):
-        raise NotImplementedError
+        try:
+            await self._process_messages_loop(recv_message)
+        finally:
+            # Call the hook provided for derived classes
+            await self.connection_lost()
 
     async def process_messages(self, recv_message):
-        async with self._group:
-            await self._group.spawn(self._process_messages, recv_message)
+        async with self._group as group:
+            await group.spawn(self._process_messages, recv_message)
+
+            # Remove tasks
+            async for task in group:
+                task.result()
 
     def unanswered_request_count(self):
         '''The number of requests received but not yet answered.'''
@@ -262,7 +269,7 @@ class MessageSession(SessionBase):
     '''Session class for protocols where messages are not tied to responses,
     such as the Bitcoin protocol.
     '''
-    async def _process_messages(self, recv_message):
+    async def _process_messages_loop(self, recv_message):
         while True:
             try:
                 message = await recv_message()
@@ -314,8 +321,6 @@ class MessageSession(SessionBase):
         except ExcessiveSessionCostError:
             self.on_disconnect_due_to_excessive_session_cost()
             await self.close()
-        except CancelledError:
-            raise
         except Exception:
             self.logger.exception(f'exception handling {message}')
             self._bump_errors()
@@ -436,7 +441,9 @@ class RPCSession(SessionBase):
             self.logger.info(f'changing outgoing request concurrency to {target} from {current}')
             self._outgoing_concurrency.set_target(target)
 
-    async def _process_messages(self, recv_message):
+    async def _process_messages_loop(self, recv_message):
+        # The loop will exit when recv_message raises a ConnectionLost error; which is also
+        # arranged when close() is called.
         while True:
             try:
                 message = await recv_message()
@@ -484,8 +491,6 @@ class RPCSession(SessionBase):
             self.on_disconnect_due_to_excessive_session_cost()
             result = RPCError(JSONRPC.EXCESSIVE_RESOURCE_USAGE, 'excessive resource usage')
             disconnect = True
-        except CancelledError:
-            raise
         except Exception:
             self.logger.exception(f'exception handling {request}')
             result = RPCError(JSONRPC.INTERNAL_ERROR, 'internal server error')
@@ -514,12 +519,10 @@ class RPCSession(SessionBase):
                 if len(self._req_times) >= self.recalibrate_count:
                     self._recalc_concurrency()
 
+    # External API
     async def connection_lost(self):
-        await super().connection_lost()
-        # Cancel pending requests and message processing
         self.connection.cancel_pending_requests()
 
-    # External API
     def default_connection(self):
         '''Return a default connection if the user provides none.'''
         return JSONRPCConnection(JSONRPCv2)
