@@ -4,12 +4,16 @@ import logging
 import sys
 import time
 from contextlib import suppress
-from functools import partial
 
 import pytest
 
-from aiorpcx import *
-from aiorpcx.session import Concurrency, SessionBase
+from aiorpcx import (
+    MessageSession, ProtocolError, sleep, spawn, TaskGroup, BitcoinFramer, SOCKS5, SOCKSProxy,
+    connect_rs, JSONRPC, Batch, RPCError, TaskTimeout, RPCSession, timeout_after, serve_rs,
+    NewlineFramer, BatchError, ExcessiveSessionCostError, SessionKind, ReplyAndDisconnect,
+    ignore_after, handler_invocation, CancelledError,
+)
+from aiorpcx.session import Concurrency
 from util import RaiseTest
 
 
@@ -90,6 +94,7 @@ def server_port(unused_tcp_port, event_loop):
         tasks = asyncio.all_tasks(event_loop)
     else:
         tasks = asyncio.Task.all_tasks(loop=event_loop)
+
     async def close_all():
         server.close()
         await server.wait_closed()
@@ -104,7 +109,7 @@ class TestRPCSession:
     async def test_no_proxy(self, server_port):
         proxy = SOCKSProxy('localhost:79', SOCKS5, None)
         with pytest.raises(OSError):
-            async with connect_rs('localhost', server_port, proxy=proxy) as session:
+            async with connect_rs('localhost', server_port, proxy=proxy):
                 pass
 
     @pytest.mark.asyncio
@@ -231,8 +236,8 @@ class TestRPCSession:
             session.verbosity = 4
             with caplog.at_level(logging.DEBUG):
                 await session.send_request('echo', ['wait'])
-            assert in_caplog(caplog, "sending message b'{")
-            assert in_caplog(caplog, "received data b'{")
+            assert in_caplog(caplog, "sending message b")
+            assert in_caplog(caplog, "received data b")
 
     @pytest.mark.asyncio
     async def test_framer_MemoryError(self, server_port, caplog):
@@ -278,8 +283,9 @@ class TestRPCSession:
         async with connect_rs('localhost', server_port) as session:
             protocol = session.transport
             assert protocol._can_send.is_set()
+            asyncio_transport = protocol._asyncio_transport
             try:
-                protocol.transport.write = my_write
+                asyncio_transport.write = my_write
             except AttributeError:    # uvloop: transport.write is read-only
                 return
             await session._send_message(b'a')
@@ -290,7 +296,7 @@ class TestRPCSession:
             async def monitor():
                 await sleep(0.002)
                 assert called == [b'A\n', b'very\n']
-                assert not protocol_can_send.is_set()
+                assert not protocol._can_send.is_set()
                 protocol.resume_writing()
                 assert protocol._can_send.is_set()
 
@@ -303,6 +309,7 @@ class TestRPCSession:
             limit = None
             # Check idempotent
             protocol.resume_writing()
+            assert task.result() is None
 
     @pytest.mark.asyncio
     async def test_slow_connection_aborted(self, server_port):
@@ -314,7 +321,7 @@ class TestRPCSession:
             assert not protocol._can_send.is_set()
             task = await spawn(session._send_message(b'a'))
             await sleep(0.1)
-            assert task.cancelled()
+            assert isinstance(task.exception(), TaskTimeout)
             assert protocol._can_send.is_set()
             assert session.is_closing()
 
@@ -594,16 +601,16 @@ class TestWireResponses(object):
                     "id": 1}
             await session.send(item)
             assert await session.response() == {"jsonrpc": "2.0",
-                                               "result": [42, 43], "id": 1}
+                                                "result": [42, 43], "id": 1}
 
     @pytest.mark.asyncio
     async def test_send_request_named(self, server_port):
         async with connect_wire_session('localhost', server_port) as session:
             item = {"jsonrpc": "2.0", "method": "echo", "params":
-                    {"value" : [42, 43]}, "id": 3}
+                    {"value": [42, 43]}, "id": 3}
             await session.send(item)
             assert await session.response() == {"jsonrpc": "2.0",
-                                               "result": [42, 43], "id": 3}
+                                                "result": [42, 43], "id": 3}
 
     @pytest.mark.asyncio
     async def test_send_notification(self, server_port):
@@ -697,9 +704,9 @@ class TestWireResponses(object):
                         "id": 0}]
             await session.send(item)
             assert await session.response() == [
-                { "jsonrpc": "2.0", "id": None,
-                  "error": {"code": -32600, "message":
-                            "request object must be a dictionary"}},
+                {"jsonrpc": "2.0", "id": None,
+                 "error": {"code": -32600, "message":
+                           "request object must be a dictionary"}},
                 {"jsonrpc": "2.0", "result": 42, "id": 0}]
 
     @pytest.mark.asyncio
@@ -756,6 +763,7 @@ class MessageServer(MessageSession):
         elif command == b'sleep':
             await sleep(0.2)
 
+
 @pytest.fixture
 def msg_server_port(event_loop, unused_tcp_port):
     coro = serve_rs(MessageServer, 'localhost', unused_tcp_port, loop=event_loop)
@@ -765,6 +773,7 @@ def msg_server_port(event_loop, unused_tcp_port):
         tasks = asyncio.all_tasks(event_loop)
     else:
         tasks = asyncio.Task.all_tasks(loop=event_loop)
+
     async def close_all():
         server.close()
         await server.wait_closed()
@@ -784,6 +793,7 @@ class TestMessageSession(object):
         async with connect_message_session('localhost', msg_server_port) as session:
             server_session = await MessageServer.current_server()
             await session.send_message((b'version', b'abc'))
+        await sleep(0.02)
         assert server_session.messages == [(b'version', b'abc')]
 
     @pytest.mark.asyncio
@@ -888,7 +898,7 @@ class TestConcurrency:
                     counter += 1
                     in_flight += 1
                     await sleep(pause)
-                    in_flight -=1
+                    in_flight -= 1
 
             async with TaskGroup() as group:
                 for n in range(100):
@@ -945,7 +955,8 @@ class TestConcurrency:
             if n == 1:
                 c.set_target(1)
 
-        tasks = [await spawn(worker, n) for n in range(1, 4)]
+        for n in range(1, 4):
+            await spawn(worker, n)
         # Whilst this task sleeps, the sequence is:
         # Worker 1 grabs C and sleeps
         # Worker 2 grabs C and sleeps
@@ -960,5 +971,5 @@ class TestConcurrency:
         # sleeping.  If it doesn't, worker 2, on exiting its context block, thinks nothing else
         # nothing is trying to retarget the semaphore, and so reduces C._sem_value instead
         # of releasing the semaphore.  This means that worker 3 never wakes up.
-        await sleep(0.02)
+        await sleep(0.05)
         assert not c._semaphore.locked()
